//
//  MyViewController.m
//  ScrollViewSample
//

#import "MyViewController.h"

@interface MyViewController ()

@end

@implementation MyViewController

- (void)viewDidLoad
{
    [super viewDidLoad];
    
    // ScrollViewのdelegateをViewController自身に設定
    _scrollView.delegate = self;
    _scrollView.minimumZoomScale = 0.5f;    // 最小拡大率
    _scrollView.maximumZoomScale = 3.0f;    // 最大拡大率
    _scrollView.zoomScale = 1.0f;           // 表示時の拡大率
}

/**
 * 拡大縮小対象のViewを返す
 */
- (UIView *)viewForZoomingInScrollView:(UIScrollView *)scrollView
{
    return self.imageView;
}

/**
 * ScrollViewが拡大縮小されるたびに呼び出される
 */
- (void)scrollViewDidZoom:(UIScrollView *)scrollView
{
    [self updateImageCenter];
}

/**
 * ScrollViewの拡大縮小終了時に呼び出される
 */
- (void)scrollViewDidEndZooming:(UIScrollView *)scrollView
                       withView:(UIView *)view
                        atScale:(CGFloat)scale
{
    [self updateImageCenter];
}

/**
 * 拡大縮小された画像のサイズに合わせて中央座標を変更する
 */
- (void)updateImageCenter
{
    // 画像の表示サイズを取得
    CGSize imageSize = self.imageView.image.size;
    imageSize.width *= self.scrollView.zoomScale;
    imageSize.height *= self.scrollView.zoomScale;
    
    // サブスクロールビューのサイズを取得
    CGRect  bounds = self.scrollView.bounds;
    
    // イメージビューの中央の座標を計算
    CGPoint point;
    point.x = imageSize.width / 2;
    if (imageSize.width < bounds.size.width) {
        point.x += (bounds.size.width - imageSize.width) / 2;
    }
    point.y = imageSize.height / 2;
    if (imageSize.height < bounds.size.height) {
        point.y += (bounds.size.height - imageSize.height) / 2;
    }
    self.imageView.center = point;
}

@end
